ams.opt.Objective
=================

.. currentmodule:: ams.opt

.. autoclass:: Objective

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~Objective.evaluate
       
       
          ~Objective.parse
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~Objective.class_name
      ~Objective.e
      ~Objective.n
      ~Objective.shape
      ~Objective.size
      ~Objective.v
   
   